package com.iosoftware.ld22lma;

import java.io.*;
import java.awt.*;
import java.awt.image.*;

import javax.swing.*;
import javax.imageio.*;

public class Misc {
	public static void makeSS(JPanel p) {
		BufferedImage ssImg = new BufferedImage(600, 400,
				BufferedImage.TYPE_INT_RGB);
		Graphics2D g = ssImg.createGraphics();
		p.paint(g);
		try {
			File file = new File("C:/LMASS/");
			file.mkdirs();
			ImageIO.write(ssImg, "png",
					new File("C:/LMASS/" + System.currentTimeMillis() + ".png"));
		} catch (Exception ex) {
			ex.printStackTrace();
		}
		g.dispose();
		ssImg.flush();
		System.out.println("Screenshot taken!");
	}
	
	public static double positionsToRotation(double x1, double y1, double x2, double y2) {
		if(x1 == x2 && y1 == y2) {
			return 0;
		}
		double t = (y2-y1)/(x2-x1);
		if(x2 < x1) {
			return Math.PI+Math.atan(t);
		} else {
			return Math.atan(t);
		}
	}

	public static boolean isOutOfMap(Vector2D v, boolean tolerance) {
		return (tolerance && (v.x < -50d || v.y < -50d || v.x >= 650d || v.y >= 450d))
				|| (!tolerance && (v.x < 0 || v.y < 0 || v.x >= 600d || v.y >= 400d));
	}

	public static double normalizeRotation(double rotation) {
		double temp = rotation % (Math.PI * 2d);
		return rotation < 0 ? (Math.PI * 2d) + temp : temp;
	}

	public static int getRandomInt(int maxint) {
		return (int) Math.floor(Math.random() * maxint);
	}

	public static void drawImage(Image img, int x, int y, Graphics2D g) {
		Color c = g.getColor();
		g.setColor(Color.DARK_GRAY);
		g.fillRect(x, y, 60, 60);
		g.setColor(Color.WHITE);
		g.fillRect(x + 5, y + 5, 50, 50);
		g.drawImage(img, x + 5, y + 5, null);
		g.setColor(c);
	}

	public static void drawCenteredString(String s, int offx, int offy, int w,
			int h, Graphics g) {
		FontMetrics fm = g.getFontMetrics();
		int x = offx + (w - fm.stringWidth(s)) / 2;
		int y = offy
				+ (fm.getAscent() + (h - (fm.getAscent() + fm.getDescent())) / 2);
		g.drawString(s, x, y);
	}

	public static void drawShadowedCenteredString(String s, int offx, int offy,
			int w, int h, Graphics g) {
		Color color = g.getColor();
		Color colShadow = new Color(0, 0, 0, color.getAlpha());
		g.setColor(colShadow);
		drawCenteredString(s, offx + 1, offy + 1, w, h, g);
		g.setColor(color);
		drawCenteredString(s, offx, offy, w, h, g);
	}

	public static void drawVerticalCenteredString(String s, int x, int offy,
			int h, Graphics g) {
		FontMetrics fm = g.getFontMetrics();
		int y = offy
				+ (fm.getAscent() + (h - (fm.getAscent() + fm.getDescent())) / 2);
		g.drawString(s, x, y);
	}

	public static void drawStringRight(String s, int x, int y, Graphics g) {
		g.drawString(s, x - stringLength(s, g), y);
	}

	public static int stringLength(String str, Font font, Graphics g) {
		return g.getFontMetrics(font).stringWidth(str);
	}

	public static int stringLength(String str, Graphics g) {
		return g.getFontMetrics().stringWidth(str);
	}
	
	public static InputStream getFileAsInputStream(String path) {
		return Misc.class.getResourceAsStream(path);
	}
	
	public static void sleep(long time) {
		try {
			Thread.sleep(time);
		} catch(Exception ex) {
			ex.printStackTrace();
		}
	}

	public static Image loadImage(String path) {
		Image img = null;
		try {
			InputStream in = Misc.class.getResourceAsStream(path);
			if (in == null) {
				return null;
			}
			img = ImageIO.read(in);
		} catch (Exception ex) {
			ex.printStackTrace();
		}
		return img;
	}

	public static Image[] loadImages(String path, int w, int h) {
		Image s = loadImage(path);
		if (s == null) {
			return new Image[0];
		}
		Image[] imgs = new Image[w * h];
		int sx = s.getWidth(null) / w;
		int sy = s.getHeight(null) / h;
		BufferedImage i;
		Graphics2D g;
		for (int x = 0; x < w; x++) {
			for (int y = 0; y < h; y++) {
				i = new BufferedImage(sx, sy, BufferedImage.TYPE_INT_ARGB);
				g = i.createGraphics();
				g.drawImage(s, 0, 0, sx, sy, sx * x, sy * y, sx * x + sx, sy
						* y + sy, null);
				g.dispose();
				imgs[y * w + x] = i;
			}
		}
		s.flush();
		return imgs;
	}
}
